@@ -2,11 +2,11 @@
 # 
 #	Internal functions and wrappers from Fortran
 #	Author: Claudio Agostinelli and Victor J. Yohai
-#	E-mail: claudio@unive.it
-#	Date: September, 14, 2017
-#	Version: 0.2-1
+#	E-mail: claudio.agostinelli@unitn.it
+#	Date: May, 21, 2019
+#	Version: 0.2-2
 #
-#	Copyright (C) 2014-2017 Claudio Agostinelli
+#	Copyright (C) 2014-2019 Claudio Agostinelli
 #                      and Victor J. Yohai
 #
 #############################################################
@@ -28,7 +28,7 @@ rssr <- function(resid, Sigma) {
     as.integer(JL),
     as.matrix(Sigma),
     rssr=matrix(0, nrow=JL, ncol=n),
-    package="robustvarComp")$rssr
+    PACKAGE="robustvarComp")$rssr
   return(rssr)
 }
 
@@ -44,7 +44,7 @@ rsr <- function(resid, Sigma) {
     as.integer(JL),
     as.matrix(Sigma),
     rsr=matrix(0, nrow=JL, ncol=n),
-    package="robustvarComp")$rsr
+    PACKAGE="robustvarComp")$rsr
   return(rsr)
 }
 
@@ -63,7 +63,7 @@ xssx <- function(x, Sigma) {
     as.integer(JL),
     as.matrix(Sigma),
     xssx=array(0.0, dim=c(JL,n,k,k)),
-    package="robustvarComp")$xssx
+    PACKAGE="robustvarComp")$xssx
   return(xssx)
 }
 
@@ -83,7 +83,7 @@ xssy <- function(x, y, Sigma) {
     as.integer(JL),
     as.matrix(Sigma),
     xssy=array(0.0, dim=c(JL,n,k)),
-    package="robustvarComp")$xssy
+    PACKAGE="robustvarComp")$xssy
   return(xssy)
 }
 
@@ -101,7 +101,7 @@ rvr <- function(resid, V) {
     as.array(V),
     as.integer(R),
     rvr=array(0.0, dim=c(JL,n,R)),
-    package="robustvarComp")$rvr
+    PACKAGE="robustvarComp")$rvr
   return(rvr)
 }
 
@@ -114,7 +114,7 @@ sdet <- function(Sigma) {
     as.integer(p),
     as.integer(JL),
     sigmadet=double(JL),
-    package="robustvarComp")$sigmadet
+    PACKAGE="robustvarComp")$sigmadet
   return(sigmadet)
 }
 
@@ -457,7 +457,7 @@ doSsteppw <- function(RR, scale, bb, cc, psi, tol=10^(-8), verbose=FALSE) {
       as.double(cc),
       as.integer(psi),                
       as.double(tol),
-      package="robustvarComp")[[4]]
+      PACKAGE="robustvarComp")[[4]]
   return(S)
 }
 
@@ -475,7 +475,7 @@ doSstep <- function(m, scale, bb, cc, psi, tol=10^(-8), verbose=FALSE) {
     as.double(cc),
     as.integer(psi),
     as.double(tol),
-    package="robustvarComp")[[3]]
+    PACKAGE="robustvarComp")[[3]]
   return(scale)
 }
 
@@ -492,7 +492,7 @@ doSsteprocke <- function(m, scale, bb, p, arp, tol=10^(-8), verbose=FALSE) {
     as.integer(p),
     as.double(dq),
     as.double(tol),
-    package="robustvarComp")[[3]]
+    PACKAGE="robustvarComp")[[3]]
   return(scale)
 }
 
@@ -507,14 +507,14 @@ rhostar <- function(m, scale, cc, psi) {
       as.integer(n),
       as.double(scale),
       as.double(cc),
-      package="robustvarComp")[[1]]
+      PACKAGE="robustvarComp")[[1]]
   else if (psi=="optimal")
     m <- .Fortran("soptimch",
       as.double(m),
       as.integer(n),
       as.double(scale),
       as.double(cc),
-      package="robustvarComp")[[1]]
+      PACKAGE="robustvarComp")[[1]]
 ##    m <- Mchi(x=sqrt(m/scale), cc=cc, psi=psi)
   return(m)
 }
@@ -535,7 +535,7 @@ rhostarpw <- function(RR, scale, cc, psi) {
     as.double(cc),
     as.integer(psi),
     A=double(JL),
-    package="robustvarComp")$A
+    PACKAGE="robustvarComp")$A
   return(A)
 }
 
@@ -564,7 +564,7 @@ doTausteppw <- function(RR, scale, cc, psi) {
     as.double(cc),
     as.integer(psi),        
     T=double(1),
-    package="robustvarComp")$T
+    PACKAGE="robustvarComp")$T
 ####    T <- sum(scale*rhostarpw(RR, scale, cc))
   return(T)
 }
@@ -585,7 +585,7 @@ doTausteppwDet <- function(RR, scale, cc, psi, detS) {
     as.integer(psi),
     as.double(detS),
     T=double(1),
-    package="robustvarComp")$T
+    PACKAGE="robustvarComp")$T
 ####    T <- sum(scale*rhostarpw(RR, scale, cc))
   return(T)
 }
